@@ -40,7 +40,7 @@
 #'   tangential = TRUE
 #' )
 #' dat <- san_andreas[order(distance), ]
-#' roll_circstats(dat$azi, w = 1 / dat$unc, circular_mean, width = 51)
+#' roll_circstats(dat$azi, w = 1 / dat$unc, circular_mean, width = 51) |> head()
 roll_circstats <- function(x, w = NULL,
                            FUN,
                            axial = TRUE, na.rm = TRUE,
@@ -118,12 +118,12 @@ roll_circstats <- function(x, w = NULL,
 #' )
 #' dat <- san_andreas[order(distance), ]
 #' dat.PoR <- PoR_shmax(san_andreas, PoR, "right")
-#' roll_normchisq(dat.PoR$azi.PoR, 135, dat$unc)
-#' roll_rayleigh(dat.PoR$azi.PoR, prd = 135, unc = dat$unc)
-#' roll_dispersion(dat.PoR$azi.PoR, y = 135, w = 1 / dat$unc)
-#' roll_confidence(dat.PoR$azi.PoR, w = 1 / dat$unc)
+#' roll_normchisq(dat.PoR$azi.PoR, 135, dat$unc) |> head()
+#' roll_rayleigh(dat.PoR$azi.PoR, prd = 135, unc = dat$unc) |> head()
+#' roll_dispersion(dat.PoR$azi.PoR, y = 135, w = 1 / dat$unc) |> head()
+#' roll_confidence(dat.PoR$azi.PoR, w = 1 / dat$unc) |> head()
 #' \donttest{
-#' roll_dispersion_CI(dat.PoR$azi.PoR, y = 135, w = 1 / dat$unc, R = 10)
+#' roll_dispersion_CI(dat.PoR$azi.PoR, y = 135, w = 1 / dat$unc, R = 10) |> head()
 #' }
 NULL
 
@@ -187,7 +187,7 @@ roll_dispersion <- function(x, y, w = NULL, w.y = NULL,
     width = width,
     FUN = function(x) {
       suppressMessages(
-        circular_dispersion(x[, 1], x[, 2], x[, 3], x[, 4], norm = TRUE)
+        circular_dispersion(x[, 1], x[, 2], x[, 3], x[, 4])
       )
     },
     by.column = by.column,
@@ -273,6 +273,7 @@ optimal_rollwidth <- function(x) {
 
 #' Apply Rolling Functions using Circular Statistics
 #'
+#' `r lifecycle::badge('superseded')`
 #' A generic function for applying a function to rolling margins of an array
 #' along an additional value.
 #'
@@ -295,10 +296,15 @@ optimal_rollwidth <- function(x) {
 #' (2 by default), otherwise `NA`.
 #' @param ... optional arguments to `FUN`
 #'
+#' @note `distroll_circstats()` and friends are complete, and for new code it is
+#' recommended switching to [distance_binned_stats()],
+#' which is fasrter, easier to use, more featureful, and still under active development.
+#'
 #' @return two-column vectors of (sorted) `x` and the rolled statistics along
 #' `distance`.
 #'
 #' @name rolling_test_dist
+#' @keywords internal
 #'
 #' @importFrom dplyr first arrange filter between
 #'
@@ -315,10 +321,25 @@ optimal_rollwidth <- function(x) {
 #' )
 #' dat <- san_andreas |> cbind(PoR_shmax(san_andreas, PoR, "right"))
 #'
-#' distroll_circstats(dat$azi.PoR, distance = dat$distance, w = 1 / dat$unc, FUN = circular_mean)
-#' distroll_confidence(dat$azi.PoR, distance = dat$distance, w = 1 / dat$unc)
-#' distroll_dispersion(dat$azi.PoR, y = 135, distance = dat$distance, w = 1 / dat$unc)
-#' distroll_dispersion_sde(dat$azi.PoR, y = 135, distance = dat$distance, w = 1 / dat$unc, R = 100)
+#' distroll_circstats(dat$azi.PoR,
+#'   distance = dat$distance,
+#'   w = 1 / dat$unc, FUN = circular_mean
+#' ) |> head()
+#' distroll_confidence(dat$azi.PoR, distance = dat$distance, w = 1 / dat$unc) |> head()
+#' distroll_dispersion(dat$azi.PoR,
+#'   y = 135,
+#'   distance = dat$distance, w = 1 / dat$unc
+#' ) |> head()
+#' distroll_dispersion_sde(dat$azi.PoR,
+#'   y = 135,
+#'   distance = dat$distance, w = 1 / dat$unc, R = 100
+#' ) |> head()
+#'
+#' # New functions
+#' distance_binned_stats(
+#'   dat$azi.PoR,
+#'   distance = dat$distance, width.breaks = 1, unc = dat$unc, prd = 135
+#' ) |> head()
 NULL
 
 #' @rdname rolling_test_dist
@@ -326,6 +347,8 @@ NULL
 distroll_circstats <- function(x, distance, FUN, width = NULL, min_n = 2,
                                align = c("right", "center", "left"), w = NULL,
                                sort = TRUE, ...) {
+  lifecycle::deprecate_warn("0.4.4.9009", "distroll_circstats()", "distance_binned_stats()")
+
   align <- match.arg(align)
   stopifnot(length(x) == length(distance))
   if (is.null(w)) w <- rep(1, length(x))
@@ -368,6 +391,8 @@ distroll_circstats <- function(x, distance, FUN, width = NULL, min_n = 2,
 distroll_confidence <- function(x, distance, w = NULL, width = NULL, min_n = 2,
                                 align = c("right", "center", "left"),
                                 sort = TRUE, ...) {
+  lifecycle::deprecate_warn("0.4.4.9009", "distroll_circstats()", "distance_binned_stats()")
+
   align <- match.arg(align)
   stopifnot(length(x) == length(distance))
   if (is.null(w)) w <- rep(1, length(x))
@@ -410,6 +435,8 @@ distroll_dispersion <- function(x, y, w = NULL, w.y = NULL, distance,
                                 width = NULL, min_n = 2,
                                 align = c("right", "center", "left"),
                                 sort = TRUE, ...) {
+  lifecycle::deprecate_warn("0.4.4.9009", "distroll_circstats()", "distance_binned_stats()")
+
   align <- match.arg(align)
   stopifnot(length(x) == length(distance))
   if (length(y) == 1) y <- rep(y, length(x))
@@ -455,6 +482,8 @@ distroll_dispersion_sde <- function(x, y, w = NULL, w.y = NULL, distance,
                                     width = NULL, min_n = 2,
                                     align = c("right", "center", "left"),
                                     sort = TRUE, ...) {
+  lifecycle::deprecate_warn("0.4.4.9009", "distroll_circstats()", "distance_binned_stats()")
+
   align <- match.arg(align)
   stopifnot(length(x) == length(distance))
   if (length(y) == 1) y <- rep(y, length(x))
@@ -493,3 +522,121 @@ distroll_dispersion_sde <- function(x, y, w = NULL, w.y = NULL, distance,
   }
   return(cbind(distance = ds, x = res, n = ns))
 }
+
+
+#' Distance Binned Summary Statistics
+#'
+#' `r lifecycle::badge('experimental')`
+#' Circular summary statistics over intervals of distances.
+#'
+#' @param azi numeric. Azimuth values in degrees.
+#' @param prd (optional) numeric. A predicted orientation in degrees.
+#' @param prd.error (optional) numeric. The uncertainty of the predicted
+#' orientation in degrees.
+#' @param distance  numeric. the independent variable along the values in `azi`
+#' are sorted, e.g. the plate boundary distances
+#' @param n.breaks numeric. number (greater than or equal to 2) giving the
+#' number of equal-sized intervals into which `distance` is to be cut.
+#' Default is 10. Will be ignored if `width.breaks` is specified.
+#' @param width.breaks numeric. The width of the intervals into which `distance`
+#' is to be cut.
+#' @param unc (optional) Uncertainties of `azi` (in degrees) acting as inverse
+#' weighting factors for statistics.
+#' @param kappa numeric. Concentration parameter applied for the circular mode.
+#' @param R integer. Number of bootstrap iterates for estimating the error of
+#' the dispersion.
+#' @param conf.level The level of confidence for confidence interval and
+#' bootstrapped standard error of dispersion.
+#' @param ... optional arguments passed to [ggplot2::cut_interval()] and [[ggplot2::cut_width()]
+#'
+#' @return tibble containing the `n` values for `azi`in each bin, min/median/max
+#' distance of the bin, and the summary statistics for `azi`.
+#' If `prd` is specified, the normal Chi-squared statistic, dispersion and its
+#' standard error are returned as well.
+#'
+#' @importFrom dplyr tibble mutate summarise select
+#' @importFrom ggplot2 cut_width cut_number
+#'
+#' @seealso [circular_summary()], [circular_dispersion()], and [circular_dispersion_boot()]
+#'
+#' @export
+#'
+#' @examples
+#' data("plates")
+#' plate_boundary <- subset(plates, plates$pair == "na-pa")
+#' data("san_andreas")
+#' PoR <- subset(nuvel1, nuvel1$plate.rot == "na")
+#' san_andreas$distance <- distance_from_pb(
+#'   x = san_andreas,
+#'   PoR = PoR,
+#'   pb = plate_boundary,
+#'   tangential = TRUE
+#' )
+#' dat <- san_andreas |> cbind(PoR_shmax(san_andreas, PoR, "right"))
+#'
+#' distance_binned_stats(dat$azi.PoR,
+#'   distance = dat$distance, width.breaks = 1,
+#'   unc = dat$unc, prd = 135
+#' ) |> head()
+distance_binned_stats <- function(azi, distance, n.breaks = 10, width.breaks = NULL,
+                                  unc = NULL, prd = NULL, prd.error = NULL,
+                                  kappa = 2, R = 1000, conf.level = 0.95, ...) {
+  lifecycle::signal_stage("experimental", "distance_binned_stats()")
+  stopifnot(length(azi) == length(distance))
+
+  # binding of to be defined variables
+  n <- w <- w.prd <- nchisq <- dispersion <- dispersion_sde <- NULL
+
+  if (!is.null(width.breaks)) {
+    bins <- ggplot2::cut_width(distance, width.breaks, ...)
+  } else {
+    bins <- ggplot2::cut_number(distance, n.breaks, ...)
+  }
+  no_prd <- is.null(prd)
+
+  res <- dplyr::tibble(
+    azi = azi,
+    unc = unc,
+    prd = prd,
+    prderr = prd.error,
+    distance = distance,
+    bins = bins
+  ) |>
+    dplyr::mutate(
+      # bins = cut(distance, n = n.breaks, ...),
+      # bins = cut_fun(distance, cut_param, ...),
+      w = ifelse(is.null(unc), 1, 1 / unc),
+      w.prd = ifelse(is.null(prd.error), 1, 1 / prd.error),
+      prd = ifelse(is.null(prd), NA, prd)
+    ) |>
+    dplyr::group_by(bins) |>
+    dplyr::summarise(
+      n = length(azi),
+      distance_min = min(distance),
+      distance_median = stats::median(distance, na.rm = TRUE),
+      distance_max = max(distance),
+      mean = ifelse(n > 2, circular_mean(azi, w = w), NA),
+      sd = ifelse(n > 2, circular_sd(azi, w = w), NA),
+      var = ifelse(n > 2, circular_var(azi, w = w), NA),
+      lq = ifelse(n > 3, circular_quantiles(azi, w = w)[1], NA),
+      quasimedian = ifelse(n > 2, circular_median(azi, w = w), NA),
+      uq = ifelse(n > 3, circular_quantiles(azi, w = w)[3], NA),
+      median = circular_sample_median(azi),
+      mode = ifelse(n > 2, circular_mode(azi, kappa = kappa), NA),
+      CI = ifelse(n > 2, confidence_angle(azi, w = w, conf.level = conf.level), NA),
+      skewness = ifelse(n > 2, second_central_moment(azi, w = w)$skewness, NA),
+      kurtosis = ifelse(n > 2, second_central_moment(azi, w = w)$kurtosis, NA),
+      nchisq = norm_chisq(azi, prd, w),
+      dispersion = ifelse(n > 2, circular_dispersion(azi, prd, w = w, w.y = w.prd), NA),
+      dispersion_sde = ifelse(n > 2, circular_dispersion_boot(azi, prd,
+        w = w, w.y = w.prd,
+        conf.level = conf.level, R = R
+      )$sde, NA)
+    )
+
+  if (no_prd) {
+    dplyr::select(res, -c(nchisq, dispersion, dispersion_sde))
+  } else {
+    res
+  }
+}
